@@ -12,7 +12,7 @@
     <message>
         <location filename="../src/policykitagent.cpp" line="81"/>
         <source>Another authentication is in progress. Please try again later.</source>
-        <translation type="unfinished"></translation>
+        <translation>تجري مصادقة أخرى الان. الرجاء معاودة المحاولة في وقت لاحق.</translation>
     </message>
     <message>
         <location filename="../src/policykitagent.cpp" line="151"/>
@@ -34,19 +34,16 @@
     <name>PolicykitAgentGUI</name>
     <message>
         <location filename="../src/policykitagentgui.ui" line="14"/>
-        <location filename="../build/lxqt-policykit-agent_autogen/include/ui_policykitagentgui.h" line="100"/>
         <source>Authentication Required</source>
         <translation>الاستيثاق مطلوب</translation>
     </message>
     <message>
         <location filename="../src/policykitagentgui.ui" line="55"/>
-        <location filename="../build/lxqt-policykit-agent_autogen/include/ui_policykitagentgui.h" line="101"/>
         <source>Identity:</source>
         <translation>الهويّة:</translation>
     </message>
     <message>
         <location filename="../src/policykitagentgui.ui" line="65"/>
-        <location filename="../build/lxqt-policykit-agent_autogen/include/ui_policykitagentgui.h" line="102"/>
         <source>Password:</source>
         <translation>كلمة السر:</translation>
     </message>
